@@ -6,7 +6,7 @@ Mojo::IRC - IRC Client for the Mojo IOLoop
 
 =head1 VERSION
 
-0.18
+0.19
 
 =head1 SYNOPSIS
 
@@ -137,7 +137,7 @@ use constant DEFAULT_CERT => $ENV{MOJO_IRC_CERT_FILE} || catfile dirname(__FILE_
 use constant DEFAULT_KEY  => $ENV{MOJO_IRC_KEY_FILE}  || catfile dirname(__FILE__), 'mojo-irc-client.key';
 use constant OFFLINE => $ENV{MOJO_IRC_OFFLINE} ? 1 : 0;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 my %CTCP_QUOTE = ("\012" => 'n', "\015" => 'r', "\0" => '0', "\cP" => "\cP");
 
@@ -158,7 +158,7 @@ The name of this IRC client. Defaults to "Mojo IRC".
 
 =head2 nick
 
-IRC nick name accessor.
+IRC nick name accessor. Default to L</user>.
 
 =head2 parser
 
@@ -200,18 +200,18 @@ This can be generated using
 
 =head2 user
 
-IRC username.
+IRC username. Defaults to current logged in user or falls back to "anonymous".
 
 =cut
 
 has ioloop => sub { Mojo::IOLoop->singleton };
 has name   => 'Mojo IRC';
-has nick   => '';
+has nick   => sub { shift->user };
 has parser => sub { Parse::IRC->new; };
 has pass   => '';
 has real_host => '';
 has tls       => undef;
-has user      => '';
+has user      => sub { $ENV{USER} || getlogin || getpwuid($<) || 'anonymous' };
 
 sub server {
   my ($self, $server) = @_;
